[![Testing Koan](https://github.com/cobbler/koan/actions/workflows/testing.yml/badge.svg)](https://github.com/cobbler/koan/actions/workflows/testing.yml)
[![Building Koan packages](https://github.com/cobbler/koan/actions/workflows/packaging.yml/badge.svg)](https://github.com/cobbler/koan/actions/workflows/packaging.yml)
[![codecov](https://codecov.io/gh/cobbler/koan/branch/master/graph/badge.svg?token=wSeiJxpVNh)](https://codecov.io/gh/cobbler/koan)
[![Codacy Badge](https://app.codacy.com/project/badge/Grade/41f1b5564c9d47d2a7ad6458b2011b9b)](https://www.codacy.com/gh/cobbler/koan/dashboard?utm_source=github.com&amp;utm_medium=referral&amp;utm_content=cobbler/koan&amp;utm_campaign=Badge_Grade)
[![Gitter](https://badges.gitter.im/cobbler/koan.svg)](https://gitter.im/cobbler/koan?utm_source=badge&utm_medium=badge&utm_campaign=pr-badge)
[![Documentation Status](https://readthedocs.org/projects/koan/badge/?version=latest)](https://koan.readthedocs.io/en/latest/?badge=latest)

# Koan

Koan stands for kickstart-over-a-network and allows for both network installation of new virtualized guests and
reinstallation of an existing system. For use with a boot-server configured with Cobbler.
